@@ -30,7 +30,11 @@ class Compiler(object):
                     try:
                         infile = finders.find(input_path)
                         outfile = finders.find(output_path)
-                        outdated = self.is_outdated(input_path, output_path)
+                        if outfile is None:
+                            outfile = self.output_path(infile, compiler.output_extension)
+                            outdated = False
+                        else:
+                            outdated = self.is_outdated(input_path, output_path)
                         compiler.compile_file(infile, outfile, outdated=outdated, force=force)
                     except CompilerError:
                         if not self.storage.exists(output_path) or not settings.PIPELINE:
